OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Agregado a favoritos",
    "Removed from favorites" : "Quitado de favoritos",
    "You added {file} to your favorites" : "Has agregado {file} a tus favoritos",
    "You removed {file} from your favorites" : "Has quitado {file} de tus favoritos",
    "Favorites" : "Favoritos",
    "File changes" : "Cambios del archivo",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Borrado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renombrado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote account\"" : "\"cuenta remota\"",
    "You created {file}" : "Ha creado {file}",
    "You created an encrypted file in {file}" : "Has creado un archivo cifrado en {file}",
    "{user} created {file}" : "{user} ha creado {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creado un archivo cifrado en {file}",
    "{file} was created in a public folder" : "{file} se ha creado en una carpeta pública",
    "You changed {file}" : "Has cambiado {file}",
    "You changed an encrypted file in {file}" : "Has modificado un archivo cifrado en {file}",
    "{user} changed {file}" : "{user} ha cambiado {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha modificado un archivo cifrado en {file}",
    "You deleted {file}" : "Has borrado {file}",
    "You deleted an encrypted file in {file}" : "Has borrado un archivo cifrado en {file}",
    "{user} deleted {file}" : "{user} eliminó {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha borrado un archivo cifrado en {file}",
    "You restored {file}" : "Has restaurado {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Has renombrado {oldfile} (oculto) a {newfile} (oculto)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Has renombrado {oldfile} (oculto) a {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Has renombrado {oldfile} a {newfile} (oculto)",
    "You renamed {oldfile} to {newfile}" : "Has renombrado {oldfile} a {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renombró {oldfile} (oculto) a {newfile} (oculto)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renombró {oldfile} (oculto) a {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renombró {oldfile} a {newfile} (oculto)",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha renombrado {oldfile} a {newfile}",
    "You moved {oldfile} to {newfile}" : "Has movido {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo fue agregado o borrado de tus <strong>favoritos</strong>",
    "Files" : "Archivos",
    "A file or folder has been <strong>changed</strong>" : "Se ha <strong>modificado</strong> un archivo o carpeta",
    "A favorite file or folder has been <strong>changed</strong>" : "Un archivo o carpeta favorito ha sido <strong>cambiado</strong>",
    "Failed to authorize" : "Fallo al autorizar",
    "Invalid folder path" : "Ruta de carpeta inválida",
    "Folder not found" : "Carpeta no encontrada",
    "The file cannot be found" : "El archivo no se puede encontrar",
    "The destination path does not exist: %1$s" : "La ruta de destino no existe: %1$s",
    "You do not have permission to create a file at the specified location" : "No tienes permiso para crear un archivo en la ubicación especificada",
    "The file could not be converted." : "El archivo no se pudo convertir.",
    "Could not get relative path to converted file" : "No se pudo obtener la ruta relativa al archivo convertido",
    "Favorite files" : "Archivos favoritos",
    "No favorites" : "No hay favoritos",
    "More favorites" : "Más favoritos",
    "Upload (max. %s)" : "Subida (máx. %s)",
    "Accept" : "Aceptar",
    "Reject" : "Rechazar",
    "Incoming ownership transfer from {user}" : "Ha llegado una transferencia de propiedad de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "¿Deseas aceptar {path}?\n\nNota: El proceso de transferencia tras aceptar podría tardar hasta 1 hora.",
    "Ownership transfer denied" : "Se denegó la transferencia de propiedad",
    "Your ownership transfer of {path} was denied by {user}." : "Su transferencia de propiedad de {path} fue denegada por {user}.",
    "Ownership transfer failed" : "Fallo al transferir la propiedad",
    "Your ownership transfer of {path} to {user} failed." : "Ha fallado tu transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} failed." : "Ha fallado la transferencia de propiedad de {path} desde {user}.",
    "Ownership transfer done" : "Transferencia de propiedad realizada",
    "Your ownership transfer of {path} to {user} has completed." : "Se ha completado su transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
    "in %s" : "en %s",
    "Transferred from %1$s on %2$s" : "Se transfirió desde %1$s en %2$s",
    "Files compatibility" : "Compatibilidad de archivos",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir la restricción en nombres de archivo para asegurar que los archivos se puedan sincronizar con todos los clientes. Por defecto, se permiten todos los nombres de archivos válidos en POSIX (por ejemplo, Linux o macOS).",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "También es posible migrar los archivos automáticamente luego de habilitar este ajuste. Por favor, refiérase a la documentación sobre el comando occ.",
    "Enforce Windows compatibility" : "Forzar la compatibilidad con Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Esto bloqueará los nombres de archivos inválidos en sistemas Windows, tales como usar nombres reservados o caracteres especiales. Pero no forzará la compatibilidad del uso de mayúsculas y minúsculas.",
    "File Management" : "Gestión de archivos",
    "Home" : "Inicio",
    "Target folder does not exist any more" : "La carpeta destino ya no existe",
    "Reload current directory" : "Recargar carpeta actual",
    "Go to the \"{dir}\" directory" : "Ir a la carpeta \"{dir}\"",
    "Current directory path" : "Dirección de la carpeta actual",
    "Your have used your space quota and cannot upload files anymore" : "Ha utilizado su cuota de espacio y ya no puede subir más archivos",
    "You do not have permission to upload or create files here." : "No tiene permiso para subir o crear archivos aquí",
    "Drag and drop files here to upload" : "Arrastre y suelte archivos aquí para subirlos",
    "Favorite" : "Favorito",
    "Back" : "Atrás",
    "Toggle selection for file \"{displayName}\"" : "Alternar selección para archivo \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Alternar selección para la carpeta \"{displayName}\"",
    "File is loading" : "El archivo se está cargando",
    "Folder is loading" : "La carpeta se está cargando",
    "Filename" : "Nombre de archivo",
    "Folder name" : "Nombre de la carpeta",
    "This node is unavailable" : "Este nodo no está disponible",
    "Another entry with the same name already exists." : "Ya existe otra entrada con el mismo nombre.",
    "Invalid filename." : "Nombre de archivo inválido.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Renombrado \"{oldName}\" a \"{newName}\"",
    "Rename file" : "Renombrar archivo",
    "Folder" : "Carpeta",
    "Pending" : "Pendiente",
    "Unknown date" : "Fecha desconocida",
    "Clear filter" : "Borrar filtro",
    "Modified" : "Modificado",
    "Type" : "Tipo",
    "Active filters" : "Filtros activos",
    "Remove filter" : "Quitar filtro",
    "Total rows summary" : "Resumen de filas totales",
    "Toggle selection for all files and folders" : "Seleccionar/deseleccionar todos los archivos y carpetas",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" fallo en algunos elementos",
    "\"{displayName}\" batch action executed successfully" : "la acción en lotes \"{displayName}\" se ejecutó exitósamente",
    "\"{displayName}\" action failed" : "la acción \"{displayName}\" falló",
    "Actions" : "Acciones",
    "(selected)" : "(seleccionado)",
    "List of files and folders." : "Lista de archivos y carpetas.",
    "You have used your space quota and cannot upload files anymore." : "Has usado tu cuota de almacenamiento y ya no puedes subir más archivos.",
    "Column headers with buttons are sortable." : "Las columnas con botones en la cabecera son ordenables.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista no se muestra completamente por motivos de rendimiento. Los archivos se mostrarán a medida que navega por la lista.",
    "File not found" : "No se ha encontrado el archivo",
    "{count} selected" : "{count} seleccionados",
    "{usedQuotaByte} used" : "{usedQuotaByte} utilizados",
    "{used} of {quota} used" : "{used} usados de {quota}",
    "{relative}% used" : "{relative}% utilizado",
    "Could not refresh storage stats" : "No fue posible refrescar las estadísticas de almacenamiento",
    "Your storage is full, files can not be updated or synced anymore!" : "Su almacenamiento está lleno, ¡Ya no se pueden subir ni sincronizarse más archivos!",
    "Storage information" : "Información de almacenamiento",
    "Storage quota" : "Cuota de almacenamiento",
    "New folder" : "Nueva carpeta",
    "Create new folder" : "Crear carpeta nueva",
    "This name is already in use." : "Este nombre ya está en uso.",
    "Create" : "Crear",
    "Fill template fields" : "Rellenar los campos de la plantilla",
    "Submitting fields …" : "Enviando campos…",
    "Submit" : "Enviar",
    "Choose a file or folder to transfer" : "Elegir un archivo o carpeta para transferir",
    "Transfer" : "Transferir",
    "Transfer {path} to {userid}" : "Transferir {path} a {userid}",
    "Invalid path selected" : "Ruta de archivo seleccionada no válida.",
    "Unknown error" : "Error desconocido",
    "Ownership transfer request sent" : "Enviada la solicitud de transferencia de propiedad",
    "Cannot transfer ownership of a file or folder you do not own" : "No puede transferir la propiedad de un archivo o carpeta de la cual no es propietario",
    "Transfer ownership of a file or folder" : "Transferir la propiedad de un archivo o carpeta",
    "Choose file or folder to transfer" : "Elegir archivo o carpeta para transferir",
    "Change" : "Cambiar",
    "New owner" : "Nuevo propietario",
    "Keep {old}" : "Conservar {old}",
    "Keep without extension" : "Conservar sin extensión",
    "Use {new}" : "Usar {new}",
    "Remove extension" : "Quitar la extensión",
    "Change file extension" : "Cambiar la extensión de archivo",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Cambiar la extensión de \"{old}\" a \"{new}\" puede hacer el archivo ilegible.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Quitar la extensión \"{old}\" puede hacer el archivo ilegible.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Añadir la extensión \"{new}\" puede hacer el archivo ilegible.",
    "Do not show this dialog again." : "No mostrar este diálogo de nuevo.",
    "Select file or folder to link to" : "Selecciona archivo o carpeta a enlazar",
    "Choose {file}" : "Seleccionar {file}",
    "Share" : "Compartir",
    "Shared by link" : "Compartido por enlace",
    "Shared" : "Compartido",
    "Switch to list view" : "Cambiar a vista de lista",
    "Switch to grid view" : "Cambiar a vista de cuadrícula",
    "The file could not be found" : "El archivo no se pudo encontrar",
    "Upload was cancelled by user" : "La carga fue cancelada por el usuario",
    "Not enough free space" : "No hay espacio libre suficiente",
    "Operation is blocked by access control" : "Esta operación está bloqueada por el control de accesos",
    "Error during upload: {message}" : "Error durante la subida: {message}",
    "Error during upload, status code {status}" : "Error durante la subida, código de estado {status}",
    "Unknown error during upload" : "Error desconocido durante la subida",
    "\"{displayName}\" action executed successfully" : "la acción \"{displayName}\" se ejecutó exitosamente",
    "Loading current folder" : "Cargando carpeta actual",
    "Retry" : "Reintentar",
    "No files in here" : "Aquí no hay archivos",
    "Upload some content or sync with your devices!" : "¡Suba contenidos o sincronice sus dispositivos!",
    "Go back" : "Ir atrás",
    "Filter file names …" : "Filtrar nombres de archivo…",
    "Views" : "Vistas",
    "Files settings" : "Configuración de archivos",
    "Your files" : "Sus archivos",
    "Open in files" : "Abrir en archivos",
    "File cannot be accessed" : "No se ha podido acceder al archivo",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "El archivo no fue encontrado o no tiene permisos para verlo. Solicite al remitente que lo comparta.",
    "Clipboard is not available" : "El portapapeles no está disponible",
    "WebDAV URL copied to clipboard" : "El URL Webdav URL fue copiado al portapapeles",
    "Sort favorites first" : "Ordenar los favoritos primero",
    "Sort folders before files" : "Ordenar carpetas antes que archivos",
    "Show hidden files" : "Mostrar archivos ocultos",
    "Crop image previews" : "Recortar la previsualización de las imágenes",
    "Enable the grid view" : "Habilitar vista de cuadrícula",
    "Enable folder tree" : "Habilitar el árbol de carpetas",
    "Additional settings" : "Ajustes adicionales",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si ha habilitado 2FA, debe crear y utilizar una nueva contraseña de aplicación haciendo clic aquí.",
    "Warnings" : "Avisos",
    "Prevent warning dialogs from open or reenable them." : "Evitar que se abran los diálogos de advertencia o volver a habilitarlos.",
    "Show a warning dialog when changing a file extension." : "Mostrar un diálogo de advertencia cuando se cambia la extensión de un archivo.",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Speed up your Files experience with these quick shortcuts." : "Acelera tu experiencia con Archivos con esos atajos de teclado.",
    "Open the actions menu for a file" : "Abrir el menú de acciones para un archivo",
    "Rename a file" : "Cambiar el nombre de un archivo",
    "Delete a file" : "Eliminar un archivo",
    "Favorite or remove a file from favorites" : "Marcar o desmarcar un archivo como favorito",
    "Manage tags for a file" : "Gestionar etiquetas para un archivo",
    "Selection" : "Selección",
    "Select all files" : "Seleccionar todos los archivos",
    "Deselect all files" : "Deseleccionar todos los archivos",
    "Select or deselect a file" : "Seleccionar o deseleccionar un archivo",
    "Select a range of files" : "Seleccionar un grupo de archivos",
    "Navigation" : "Navegación",
    "Navigate to the parent folder" : "Ir a la carpeta superior",
    "Navigate to the file above" : "Ir al archivo anterior",
    "Navigate to the file below" : "Ir al archivo siguiente",
    "Navigate to the file on the left (in grid mode)" : "Ir al archivo de la izquierda (en modo cuadrícula)",
    "Navigate to the file on the right (in grid mode)" : "Ir al archivo de la derecha (en modo cuadrícula)",
    "View" : "Ver",
    "Toggle the grid view" : "Alternar vista en cuadrícula",
    "Open the sidebar for a file" : "Abrir la barra lateral de un archivo",
    "Show those shortcuts" : "Mostrar estos atajos de teclado",
    "You" : "Usted",
    "Shared multiple times with different people" : "Compartido múltiples veces con diferentes personas",
    "Error while loading the file data" : "Error al cargar los datos del archivo",
    "Owner" : "Dueño",
    "Remove from favorites" : "Quitar de favoritos",
    "Add to favorites" : "Añadir a favoritos",
    "Tags" : "Etiquetas",
    "Blank" : "Vacío",
    "Unable to create new file from template" : "No se ha podido crear un nuevo archivo desde la plantilla",
    "Pick a template for {name}" : "Elija una plantilla para {name}",
    "Create a new file with the selected template" : "Crear un nuevo archivo con la plantilla seleccionada",
    "Creating file" : "Creando el archivo",
    "Save as {displayName}" : "Guardar como {displayName}",
    "Save as …" : "Guardar como ...",
    "Converting files …" : "Convirtiendo archivos …",
    "Failed to convert files: {message}" : "Fallo al convertir archivos: {message}",
    "All files failed to be converted" : "Todos los archivos han fallado al convertirse",
    "One file could not be converted: {message}" : "Un archivo no ha podido ser convertido: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["Un archivo no pudo ser convertido","%n archivos no pudieron ser convertidos","%n archivos no pudieron ser convertidos"],
    "_One file successfully converted_::_%n files successfully converted_" : ["Un archivo convertido exitosamente","%n archivos convertidos exitosamente","%n archivos convertidos exitosamente"],
    "Files successfully converted" : "Archivos convertidos correctamente",
    "Failed to convert files" : "Fallo al convertir archivos",
    "Converting file …" : "Convirtiendo archivo …",
    "File successfully converted" : "Archivo convertido correctamente",
    "Failed to convert file: {message}" : "Fallo al convertir el archivo: {message}",
    "Failed to convert file" : "Fallo al convertir el archivo",
    "Deletion cancelled" : "Eliminación cancelada",
    "Leave this share" : "Abandonar este recurso compartido",
    "Leave these shares" : "Abandonar estos recursos compartidos",
    "Disconnect storage" : "Desconectar almacenamiento",
    "Disconnect storages" : "Desconectar almacenamientos",
    "Delete permanently" : "Eliminar de forma permanente",
    "Delete and unshare" : "Eliminar y dejar de compartir",
    "Delete file" : "Borrar archivo",
    "Delete files" : "Eliminar archivos",
    "Delete folder" : "Eliminar carpeta",
    "Delete folders" : "Eliminar carpetas",
    "Delete" : "Eliminar",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Está a punto de eliminar {count} elemento permanentemente","Está a punto de eliminar {count} elementos permanentemente.","Está a punto de eliminar {count} elementos permanentemente"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Está a punto de eliminar {count} elemento","Está a punto de eliminar {count} elementos","Está a punto de eliminar {count} elementos"],
    "Confirm deletion" : "Confirmar eliminación",
    "Cancel" : "Cancelar",
    "Moving \"{source}\" to \"{destination}\" …" : "Moviendo \"{source}\" a \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Copiando \"{source}\" a \"{destination}\" …",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "No puede mover un archivo/carpeta a sí mismo o a una sub-carpeta de sí mismo",
    "(copy)" : "(copiar)",
    "(copy %n)" : "(copiar %n)",
    "Move cancelled" : "Se canceló la movida",
    "A file or folder with that name already exists in this folder" : "Un archivo o carpeta con ese nombre ya existe en esta carpeta",
    "The files are locked" : "Los archivos están bloqueados",
    "The file does not exist anymore" : "El archivo ya no existe",
    "Choose destination" : "Elegir destino",
    "Copy to {target}" : "Copiar a {target}",
    "Copy" : "Copiar",
    "Move to {target}" : "Mover a {target}",
    "Move" : "Mover",
    "Move or copy operation failed" : "La operación de mover o copiar falló",
    "Move or copy" : "Mover o copiar",
    "Cancelled move or copy of \"{filename}\"." : "Se canceló la operación de mover o copiar de \"{filename}\".",
    "Cancelled move or copy operation" : "Se canceló la operación de mover o copiar",
    "Open folder {displayName}" : "Abrir carpeta {displayName}",
    "Open in Files" : "Abrir en Archivos",
    "Open file locally" : "Abrir archivo localmente",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "El archivo se abrirá ahora en tu dispositivo. Si esto no ocurre, por favor verifica que has instalado la aplicación de escritorio",
    "Retry and close" : "Reintentar y cerrar",
    "Open online" : "Abrir en línea",
    "Failed to redirect to client" : "Fallo al redirigir al cliente",
    "Open locally" : "Abrir localmente",
    "Rename" : "Renombrar",
    "Open details" : "Abrir detalles",
    "View in folder" : "Ver en carpeta",
    "Today" : "Hoy",
    "Last 7 days" : "Últimos 7 días",
    "Last 30 days" : "Últimos 30 días",
    "This year ({year})" : "Este año ({year})",
    "Last year ({year})" : "El año pasado ({year})",
    "Documents" : "Documentos",
    "Spreadsheets" : "Hojas de cálculo",
    "Presentations" : "Presentaciones",
    "PDFs" : "PDFs",
    "Folders" : "Carpetas",
    "Audio" : "Audio",
    "Photos and images" : "Fotos e imágenes",
    "Videos" : "Vídeos",
    "New folder creation cancelled" : "Se canceló la creación de la carpeta nueva",
    "Created new folder \"{name}\"" : "Se creó la carpeta nueva \"{name}\"",
    "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
    "Create templates folder" : "Crear carpeta de plantillas",
    "Templates" : "Plantillas",
    "New template folder" : "Nueva carpeta de plantillas",
    "In folder" : "En carpeta",
    "Search in folder: {folder}" : "Buscar en carpeta: {folder}",
    "One of the dropped files could not be processed" : "Uno de los archivos arrastrados no puede ser procesado",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Su navegador no soporta la API de Sistema de archivos. Los directorios no se cargarán",
    "No files to upload" : "Ningún archivo para subir",
    "Unable to create the directory {directory}" : "No se pudo crear el directorio {directory}",
    "Some files could not be uploaded" : "No se pudieron subir algunos archivos",
    "Files uploaded successfully" : "Se subieron los archivos exitosamente",
    "No files to process" : "No hay archivos para procesar",
    "Some files could not be copied" : "Algunos archivos no se pudieron copiar",
    "Some files could not be moved" : "No se ha podido mover algunos archivos",
    "Files copied successfully" : "Archivos copiados exitosamente",
    "Files moved successfully" : "Archivos movidos exitosamente",
    "Conflicts resolution skipped" : "Resolución de conflictos omitida",
    "Upload cancelled" : "Subida cancelada.",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verifique los registros o contacte con el administrador",
    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente",
    "Unexpected error: {error}" : "Error inesperado: {error}",
    "_%n file_::_%n files_" : ["%n archivo","%n archivos","%n archivos"],
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
    "_%n hidden_::_%n hidden_" : ["%n oculto","%n ocultos","%n ocultos"],
    "Filename must not be empty." : "El nombre de archivo no debe estar vacío.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" no está permitido en el nombre de archivo.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" es un nombre reservado y no se permite para los nombres de archivo.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" no es un tipo de archivo permitido.",
    "Filenames must not end with \"{extension}\"." : "Los nombres de archivo no puede terminar con \"{extension}\".",
    "List of favorite files and folders." : "Lista de archivos y carpetas favoritos.",
    "No favorites yet" : "Aún no hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que has marcado como favoritos",
    "All files" : "Todos los archivos",
    "List of your files and folders." : "Lista de sus archivos y carpetas.",
    "All folders" : "Todas las carpetas",
    "Personal files" : "Archivos personales",
    "List of your files and folders that are not shared." : "Lista de sus archivos y carpetas que no están compartidos.",
    "No personal files found" : "No se encontraron archivos personales",
    "Files that are not shared will show up here." : "Los archivos y carpetas que no ha compartido aparecerán aquí.",
    "Recent" : "Reciente",
    "List of recently modified files and folders." : "Lista de archivos y carpetas modificados recientemente.",
    "No recently modified files" : "No hay archivos modificados recientemente.",
    "Files and folders you recently modified will show up here." : "Los archivos y carpetas que ha modificado recientemente aparecerán aquí.",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Subida demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que está intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
    "File could not be found" : "El archivo no se ha encontrado",
    "Download" : "Descargar",
    "Show list view" : "Mostrar vista de lista",
    "Show grid view" : "Mostrar vista de cuadrícula",
    "Close" : "Cerrar",
    "Could not create folder \"{dir}\"" : "No se pudo crear la carpeta \"{dir}\"",
    "This will stop your current uploads." : "Esto detendrá las subidas en curso.",
    "Upload cancelled." : "Subida cancelada.",
    "Processing files …" : "Procesando archivos …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No ha sido posible subir {filename} porque es un directorio o tiene 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La carpeta de destino \"{dir}\" ya no existe",
    "An unknown error has occurred" : "Ha ocurrido un error desconocido",
    "File could not be uploaded" : "No se ha podido subir el archivo",
    "Uploading …" : "Subiendo …",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Cargando… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Subir este archivo no es compatible",
    "Error when assembling chunks, status code {status}" : "Error al reunir los trozos, código de estado {status}",
    "Choose target folder" : "Elegir carpeta de destino",
    "Set reminder" : "Establecer recordatorio",
    "Edit locally" : "Editar localmente",
    "Open" : "Abrir",
    "Could not load info for file \"{file}\"" : "No se ha podido cargar información para el archivo \"{file}\"",
    "Details" : "Detalles",
    "Please select tag(s) to add to the selection" : "Seleccione la(s) etiqueta(s) para añadir a la selección",
    "Apply tag(s) to selection" : "Aplicar etiqueta(s) a la selección",
    "Select directory \"{dirName}\"" : "Seleccione la carpeta \"{dirName}\"",
    "Select file \"{fileName}\"" : "Seleccione el archivo \"{fileName}\"",
    "Unable to determine date" : "No se ha podido determinar la fecha",
    "Could not move \"{file}\", target exists" : "No se pudo mover \"{file}\", ya existe",
    "Could not move \"{file}\"" : "No se pudo mover \"{file}\"",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "No se ha podido copiar \"{file}\", ya existe el destino",
    "Could not copy \"{file}\"" : "No se ha podido copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "Se ha copiado {origin} dentro de {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Se han copiado {origin} y {nbfiles} otros archivos dentro de {destination}",
    "{newName} already exists" : "{newName} ya existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "No se pudo renombrar \"{fileName}\", ya no existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya está en uso en la carpeta \"{dir}\". Por favor elija un nombre diferente.",
    "Could not rename \"{fileName}\"" : "No se pudo renombrar \"{fileName}\"",
    "Could not create file \"{file}\"" : "No se pudo crear archivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No se pudo crear archivo \"{file}\" porque ya existe",
    "Could not create folder \"{dir}\" because it already exists" : "No se ha podido crear la carpeta \"{dir}\" porque ya existe",
    "Could not fetch file details \"{file}\"" : "No se pudieron obtener los detalles de \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Error al borrar el archivo \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No hay resultados de búsqueda en otras carpetas para  {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Escriba más de dos caracteres para buscar en otras carpetas",
    "{dirs} and {files}" : "{dirs} y {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos","incluyendo %n ocultos"],
    "You do not have permission to upload or create files here" : "No tiene permiso para subir o crear archivos aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos","Subiendo %n archivos"],
    "New" : "Nuevo",
    "New file/folder menu" : "Menú de carpeta/archivo nuevo",
    "Select file range" : "Seleccionar el rango de archivos",
    "{used}%" : "{used}%",
    "{used} used" : "{used} usados",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "\"/\" is not allowed inside a file name." : "\"/\" no se permite en un nombre de archivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no es un tipo de archivo permitido",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "El almacenamiento de {owner} está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La carpeta de grupo \"{mountPoint}\" está llena. ¡No se puede actualizar o sincronizar ningún archivo más!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "El almacenamiento externo \"{mountPoint}\" está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Tu almacenamiento está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "El almacenamiento de {owner} está casi lleno ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La carpeta de grupo \"{mountPoint}\" está casi llena ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Tu almacenamiento está casi lleno ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coinciden \"{filter}\"","coincide \"{filter}\"","coincide \"{filter}\""],
    "Direct link was copied (only works for people who have access to this file/folder)" : "El enlace directo fue copiado (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Favorited" : "Agregado a favoritos",
    "Copy direct link (only works for people who have access to this file/folder)" : "El enlace directo fue copiado (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "Upload file" : "Subir archivo",
    "Not favorited" : "Quitado como favorito",
    "An error occurred while trying to update the tags" : "Se produjo un error al tratar de actualizar las etiquetas",
    "You don't have permission to upload or create files here." : "No tiene permisos para subir o crear archivos aquí.",
    "Storage informations" : "Informaciones de almacenamiento",
    "Choose file" : "Elegir archivo",
    "Go to the previous folder" : "Ir a la carpeta anterior",
    "Open the files app settings" : "Abrir la configuración de la app Archivos",
    "Unable to change the favourite state of the file" : "No se ha podido cambiar el estado de favorito del fichero",
    "Edit file locally" : "Editar archivo localmente",
    "Edit online" : "Editar en línea",
    "Create new templates folder" : "Crear nueva carpeta de plantillas",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetas","{folderCount} carpetas"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} archivo","{fileCount} archivos","{fileCount} archivos"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 archivo y {folderCount} carpeta","1 archivo y {folderCount} carpetas","1 archivo y {folderCount} carpetas"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} archivo y 1 carpeta","{fileCount} archivos y 1 carpeta","{fileCount} archivos y 1 carpeta"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} archivos y {folderCount} carpetas",
    "List of favorites files and folders." : "Lista de archivos y carpetas favoritos.",
    "Personal Files" : "Archivos Personales",
    "Text file" : "Archivo de texto",
    "New text file.txt" : "Nuevo archivo.txt",
    "Favored" : "Favorecido",
    "Favor" : "Favorecer",
    "Not favored" : "No favorecido",
    "Submitting fields…" : "Enviando campos…",
    "Filter filenames…" : "Filtrar nombres de archivo…",
    "{count} files could not be converted" : "{count} archivos no han podido ser convertidos",
    "{count} files successfully converted" : "{count} archivos convertidos correctamente"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
